PySensors examples
==================

Here we provide examples of how to use `PySensors` objects to solve sensor placement problems.

`PySensors overview <https://python-sensors.readthedocs.io/en/latest/examples/pysensors_overview.html>`_
----------------------------------------------------------------------------------------------------
This notebook gives an overview of most of the different tools available in `PySensors`.
It's a good place to start to get a quick idea of what the package is capable of.

`Basis comparison <https://python-sensors.readthedocs.io/en/latest/examples/basis_comparison.html>`_
----------------------------------------------------------------------------------------------------
This example compares the different basis options implemented in `PySensors` on a simple problem.

`Classification with SSPOC <https://python-sensors.readthedocs.io/en/latest/examples/classification.html>`_
----------------------------------------------------------------------------------------------------
See how to use the `SSPOC` class (Sparse Sensor Placement Optimization for Classification) to choose
sparse sets of sensors for *classification* problems.

`Cost constraints <https://python-sensors.readthedocs.io/en/latest/examples/cost_constrained_qr.html>`_
----------------------------------------------------------------------------------------------------
Learn about the `CCQR` optimizer and how it can be used to place sparse sensors when there
are variable costs associated with different locations.

`Cross validation <https://python-sensors.readthedocs.io/en/latest/examples/cross_validation.html>`_
----------------------------------------------------------------------------------------------------
`PySensors` was designed to be completely compatible with `scikit-learn`. In this notebook we show how
to perform cross-validation with `scikit-learn` objects to optimize the number of sensors and/or basis modes.

`Sea surface temperature prediciton <https://python-sensors.readthedocs.io/en/latest/examples/sea_surface_temperature.html>`_
-------------------------------------------------------------------------------------------------------------------------
See how `PySensors` can be used to pick optimal locations for sensors in the ocean to help predict the temperature of the
ocean at any given point.

`Vandermonde example <https://python-sensors.readthedocs.io/en/latest/examples/vandermonde.html>`_
----------------------------------------------------------------------------------------------------
Reproduces an example from `Manohar et al. (2018) <https://ieeexplore.ieee.org/stamp/stamp.jsp?arnumber=8361090>`_
where sensor locations are learned for a monomial basis for the task of reconstruction.


Full table of contents
----------------------
